#
# spec file for package python-dynaconf
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-dynaconf
Version:        3.2.5
Release:        2.1
Summary:        The dynamic configurator for your Python Project
License:        MIT
URL:            https://github.com/rochacbruno/dynaconf
Source:         https://github.com/rochacbruno/dynaconf/archive/%{version}.tar.gz#/dynaconf-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools >= 38.6.0}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyYAML
Requires:       python-click
Requires:       python-configobj
Requires:       python-hvac
Requires:       python-python-box
Requires:       python-python-dotenv
Requires:       python-redis
Requires:       python-setuptools
Requires:       python-toml
Requires(post): alts
Requires(postun): alts
Suggests:       python-Django
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module Django}
BuildRequires:  %{python_module Flask >= 0.12}
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module click}
BuildRequires:  %{python_module configobj}
BuildRequires:  %{python_module hvac}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module python-box}
BuildRequires:  %{python_module python-dotenv}
BuildRequires:  %{python_module redis}
BuildRequires:  %{python_module toml}
BuildRequires:  redis
# /SECTION
%python_subpackages

%description
The dynamic configurator for your Python Project

%prep
%autosetup -p1 -n dynaconf-%{version}

# require running docker with the server
rm tests/test_vault.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/dynaconf
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
%{_sbindir}/redis-server --stop-writes-on-bgsave-error no &
export DYNACONF_TEST_REDIS_URL==http://127.0.0.1:6379
%pytest tests/

%post
%python_install_alternative dynaconf

%postun
%python_uninstall_alternative dynaconf

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE
%python_alternative %{_bindir}/dynaconf
%{python_sitelib}/dynaconf
%{python_sitelib}/dynaconf-%{version}*-info

%changelog
* Mon May 26 2025 Markéta Machová <mmachova@suse.com>
- Convert to pip-based build
* Sat Apr  6 2024 Dirk Müller <dmueller@suse.com>
- update to 3.2.5:
  * `_bypass_evaluation` showing in end-user settings (#1071).
  * dependabot alert 21 about Django (on tests) (#1067).
  * include load with relative root path (#1049).
  * Add `@get` converter to alias existing keys (#1040).
  * fix wrong info about validation trigger on insantiation
  * fix incorrect combination of TOML table and inline table
  * Fix mkdocs warnings for cleaner build output (#1061).
  * Add dynaconf API to docs with mkdocstrings (#1058).
  * fix argument `env` in Validation at validation.md (#1051).
  * fix click help syntax error (#1041).
  * replace dead link to flask subclassing page (#1031).
  * Add explicit Dynaconf instantiation to sample code (#1022).
  * Fix the syntax errors in the sample program. (#1027).
  * Replace lint and formatting tools with ruff (#1074).
  * Replace/Update release script (#1078).
  * add "typos" tool and run it in codebase/docs (#1063).
  * fix create-release-commit.sh permission.
  * fix shell script in release.yml (2).
  * fix shell script in release.yml.
  * move release workflow to GitHub actions (partial) (#1043).
  * Fix misspelled variable name (#1032).
  * Fix misspelled GitHub action names on main.yml (#1033).
* Mon Jan  8 2024 Dirk Müller <dmueller@suse.com>
- update to 3.2.4:
  * allow underscore in env name
  * support for 'entrypoint-path' in FLASK_APP
  * dynaconf_merge=False on nested structures
  * non-str key raising type error
  * pin hvac minimum version
  * Hooking: Add support for changing the wrapped class
  * Hotfix bypass evaluation #984
  * Fix #976 from envvars parse True/False as booleans
  * Fix #982 glob on settings_files
  * docker compose is available on CI no need to install
  * fix(django): fix #1000 AttributeError on admin
  * Fix(django): fix #1000 AttributeError on admin (#1002) [Bruno
    Rocha]
  * Chore(lint): pep8 errors (#995) [Anderson Sousa]
  * Hooking: Add support for changing the wrapped class
  * Hotfix bypass evaluation #984
  * Fix #976 from envvars parse True/False as booleans
  * Fix #982 glob on settings_files
  * docker compose is available on CI no need to install
  * minor "utils.inspect" internal renames
  * re-write docstrings in sphinx-style (:param foo)
  * expose 'get_history'
  * refactor 'test_cli.py': use more robust test isolation
    strategy
  * add data return to 'inspect_settings' for cleaner testing
  * Docker compose is available on CI no need to install. [Bruno
    Rocha]
  * Fix #982 glob on settings_files (#987) [Bruno Rocha]
  * Fix #976 from envvars parse True/False as booleans (#983)
  * Add tests for reverse_lazy for #858
  * Add converter helper function
  * Refactor adding custom converters
  * Replace bare tries with suppress and increase codecov (#901)
  * Fix incorrect reverse_lazy workaround in docs to be correct
  * Fix anchor link in FAQ doc (#895)
  * Fix / CLI command validate not working properly (#892)
  * fix #879 with @type converter
  * add type_map to convert quoted types to proper class types
    ("int" to int)
- drop support-python-311.patch (upstream)
* Tue Feb 28 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.1.11:
  * New data key casing must adapt to existing key casing (#795)
  * Parse negative numbers from envvar Fix #799 and Fix #585 (#802)
  * Fix get command with Django (#804)
  * Allow merge_unique on lists when merge_enabled=True (#810)
  * Rebind current env when forced for Pytest Fix #728 (#809)
  * AUTO_CAST can be enabled on instance (#811)
  * Fix #807 Use client.auth.approle.login instead of client.auth_approle (#808)
  * Fix #768 of kv property depreciation from client object (#769)
  * Feature/detect casting comb token from converters (#784)
  * Using filter_strategy in env_loader to fix #760 (#767)
  * Fix cli init command for flask (#705) (#774)
  * Add unique label when merging lists to fix issue #653 (#661)
  * Add new validation to fix issue #585 (#667)
  * Add support for Python 3.10 (#665)
  * Added `dynaconf get` command to cli (#730)
  * Fix FlaskConfig.setdefault (#706)
  * Force PYTHONIOENCODING to utf-8 to fix #664 (#672)
  * Fix Issue 662 Lazy validation (#675)
  * Load vault secrets from environment less stores or which are not
    written by dynaconf (#725)
  * Added validate_only_current_env to validator (issue #734) (#736)
  * Makes Django/Flask kwargs case insensitive (#721)
  * Fix #595 namedtuples are no more converted to BoxList (#623)
  * description and type annotation for validator (#634)
  * Add support for Python 3.9 (#618)
  * Add type annotations for dynaconf.utils (#450)
  * feat: add filter strategy with PrefixFilter (#625)
  * Add a warning if `--env` is passed to `init` (#629)
- Add patch support-python-311.patch:
  * Support Python 3.11.
* Fri Jul  8 2022 Steve Kowalik <steven.kowalik@suse.com>
- Update to 3.1.4:
  * Environment variables filtering #470 (#474)
  * Test to ensure #467 is not an issue (#535)
  * Fix #478 Make alias for environment -> environments (#534)
  * Fix #462 make DynaBox nested List to use DynaBox as default class (#533)
  * Fix #511 allow user to specify loaders argument to execute_loaders (#531)
  * Fix #449 - Django lazy templating Fix #449 (#528)
  * Fix #482 - formatter case insensitive (#527)
  * Allow Title case lookup and validation. (#526)
  * Allow load_file to accept pathlib.Path (#525)
  * Case insensitive envvar traversal (#524) [Bruno Rocha]
  * Fix #521 - FlaskDynaconf should raise KeyError for non existing keys
  * Fix docs regarding --django argument on cli (#477)
  * Changed enabled_core_loaders elements to be upper case to fix #455 (#457)
  * Fix merging hyperlink to fix  #454 (#458)
  * Specify flask extension initializers by entry point object reference (#456)
  * Fix #445 casting on dottet get. (#446)
  * Fix #443 object merge with same value on same level keys (#444)
  * Fix #434 setenv failing to unset LazyValues (#437)
  * Fix colors and KEyError handling on cli.py (#429)
  * Remove links to outdated issues from guidelines.
  * Added full Dynaconf Diagram and few fizes. (#418) [Bruno Rocha]
  * Fix #407 - add proper equality test for CombinedValidator (#413)
  * HOTFIX: Logging instance has a `formatter` attribute (#410)
  * Included example of custom SOPS loader to the docs.
  * Add auth username and password for redis settings (#378)
  * Test all names in Validator("foo", "bar", must_exist=False) (#406)
  * Fix #391 make box_settings optional, change vendoring strategy (#398)
  * Fix test for versioned kv engine in latest vault. [Peng Yin]
  * Read all secrets under a vault path. [Peng Yin]
  * Allow importing SEARCHTREE before settings are configured (#383)
  * Allow testing against local redis server (#387) [John Vandenberg]
  * Fix #359 lazy template substitution on nested keys (#375)
- Remove patch redis-server-url.patch:
  * Included upstream.
- Add python-Django to BuildRequires and Suggests.
* Sun Aug  9 2020 John Vandenberg <jayvdb@gmail.com>
- Devendor the runtime package
- Activate redis tests using redis-server-url.patch
- Remove box-4.0.patch merged upstream
- Update to v3.0.0
  * Breaking change: Envless by default
  * See https://github.com/rochacbruno/dynaconf/blob/master/CHANGELOG.md
    for other changes
* Tue May 26 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Wed Apr  8 2020 Tomáš Chvátal <tchvatal@suse.com>
- Add patch from git upstream to work with latest box releases:
  * box-4.0.patch
* Wed Apr  8 2020 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.2.3:
  * Fix #236 added .local. files loading and module impersonation docs (#239)
  * Replace key.upper with `upperfy` function that keeps `__` attributes (#240)
  * Fix #241 new merge standards (#243)
  * Add support for PRELOAD_ setting. (#244)
  * Fixing how filename.local.* files are loaded (#238)
  * fix crash on empty settings (#242)
  * Fix #251 recursive call was using mutable memoized data (#254)
  * Fix #266 created new variable FORCE_ENV to override ENV_FOR_DYNACONF
  * Fix coverage for validators
  * Add support for detecting duplicate validators being added (and ignore them) (#256)
  * fix: env_loader.write: quote_mode for non-string values
  * : added line break
  * fix str comparison
  * changing quote logic
  * fix open error @py3.5
  * Fix #258 custom message for validators
  * Close #178. Included integration tests redis/vault
  * Fix #273 add Flask load extensions method.
  * Fix #145 allow lazy format using os.environ and settings values.
  * Overriding strategy test
  * Fix #203 document the usage with pytest (with examples)
* Thu Sep 26 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.1.1:
  * When both enabled, Vault has the priority over Redis for overriding (#234) [Bruno Rocha]
  * Dynaconf init will not write all possible envs, only [default] (#233) [Bruno Rocha]
  * Fixing self._root_path to fall back to os.getcwd() only when settings.load_file is called directly or from includes (#232) [Kedar Kulkarni]
  * Improvement to close #230 - do not throw error for base envs. (#231) [Bruno Rocha]
  * Fix #228 add ignore argument to Django explicit mode. (#229) [Bruno Rocha]
  * Fix typo in CLI init (#227) [Dave Barnow]
  * Add info about dunder envvars on django.md docs guide (#226) [Bruno Rocha]
  * Improve validators to use from_env method (#225) [Bruno Rocha]
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 2.1.0:
  * Nested envvars w/ DUNDER__KEYS
  * .from_env easy access to different envs
  * $dynaconf list -o export your settings as a file
  * @hashicorp #Vault & @RedisLabs supports multiple envs
* Fri Jul 26 2019 pgajdos@suse.com
- version update to 2.0.3
  * Fix #194 flask.app.config __setitem__ (#199)
  * Catch BoxKeyError when contents are TOML parsable but not keyable (#192)
  * Use the Key Value API rather than the old 'read' and 'write' methods (#198)
- package is python3 only
- test package
* Wed Jun 19 2019 Thomas Bechtold <tbechtold@suse.com>
- Initial packaging (version 2.0.2)
